==> HinemosWebClient_src-2.0.1.tar.gz: HinemosWebClient_src-2.0.1/js/monitor/scope.js <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

/*******************************************************************************
 * Create monitor scope
 */
var fn = function(_view){
	var __ = cm;
	
	 var view = $.extend({}, __._fnview_tree_grid, {
		load_flg    : false
		,facility_id: ""
		,/*
		 * Set caption of grid
		 */
		setCaption: function(path){
			this.grid.setCaption([__.getLang("scope"), ": " , path].join(""));
		}
		
		,/*
		 * On click a node of tree
		 */
		onclickTree: function(node_data){
			var _ = this
			;
			_.facility_id = node_data.facilityId;
			_.setCaption(node_data.path);
			
			if (!(_.load_flg)) {
				_.load_flg = true;
				_.reloadGrid();
			}
		}
		,/*
		 * reload Grid
		 */
		reloadGrid: function(){
			var _ = this
			;
			
			_.grid.refreshData({
				facilityId: _.facility_id
			});
		}
		
		,/*
		 * Get scope list
		 */
		createGrid: function(){
			var _ = this;
			
			$.ajax({
				url      : "get_scope_list_table_define"
				,cache   : false
				,dataType: "json"
				,type    : "get"
				,success : function(data_respond){
					// Cache local variants
					var grid = _.grid
					,pager   = grid.$pgr
					;
					
					// Check validation of data_respond
					if (__.checkJsonError(data_respond) !== true){
						return;
					}
					
					// Set some options for grid
					$.extend(data_respond,{
						url          : "get_scope_list"
						,pager       : pager
						,caption     : [__.getLang("scope"), ": "].join("")
						,sortable    : true
						,viewrecords : true
						,loadComplete: function(){
							var post_data = grid.getGridParam("postData")
							,facility_id
							;
							if((facility_id = post_data.facilityId) === undefined){
								facility_id = "";
							}
							if(facility_id === _.facility_id){
								_.load_flg = false;
							}else{
								setTimeout(function(){
									_.reloadGrid();
								}, 1);
							}
							// Set refresh data
							_view.setRefresh();
							
							// Set priority bar
							_.setPriorityStatusBar();
						}
						,ondblClickRow: function(rowid) {
                            var row_data = grid.getRowData(rowid);
                            var node_key = __.getNodeKey(_.getTree(), row_data.facilityId);
                            
                            if (typeof node_key != 'undefined') {
                                var tree = $(_.tree).dynatree("getTree");
                                tree.activateKey(node_key);
                            }
						}
					});
				
					/** Bug_11 */
					grid.processData(data_respond, ["facilityId"]);
					/***********/
					grid.controlSize();
				}
				,error   : __.loadDataError
			});
		}
		
		,/*
		 * Get facility tree
		 */
		getTree: function(){
			return __.fclt_tree.get(this._id);
		}
		
		,/*
		 * Reset data of panes of views
		 */
		resetView: function(tree){
			var _ = this;
			
			_.tree.refreshData(tree);
			_.facility_id = "";
			_.grid.refreshData({
				facilityId: ""
			}, true);
			
			_.setCaption("");
		}
		
		,/*
		 * Refresh data
		 */
		refreshData: function(){
			/** Bug_11 */
			this.grid.refreshData(null, true);
			/***********/
		}
		
		,/*
		 * Bind some action
		 */
		bindAction: function(){
			var _     = this;
			var _btns = _.$btns;
			
			// Bind actions for button in left of pane
			// Bind update grid data
			_btns.children("#update").click(function(){
				/** Bug_11 */
				_.grid.refreshData(null, true);
				/***********/
			});
			// Bind toggle left pane
			_btns.children("#toggle_view").click(function(){
				_.togglePane("west", this);
			});
		}
	});
	
	return view;
};

==> HinemosWebClient_src-2.0.2.tar.gz: HinemosWebClient_src-2.0.2/js/monitor/scope.js <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

/*******************************************************************************
 * Create monitor scope
 */
var fn = function(_view){
	var __ = cm;
	
	 var view = $.extend({}, __._fnview_tree_grid, {
		load_flg    : false
		,facility_id: ""
		,manager_ip: ""
		,/*
		 * Set caption of grid
		 */
		setCaption: function(path, managerIp){
			if (managerIp == null || managerIp == "") {
				this.grid.setCaption([__.getLang("scope"), ": " , path].join(""));
			} else {
				this.grid.setCaption([__.getLang("scope"), "(", managerIp, "): " , path].join(""));
			}
		}
		
		,/*
		 * On click a node of tree
		 */
		onclickTree: function(node_data){
			var _ = this
			;
			_.facility_id = node_data.facilityId;
			_.manager_ip = node_data.managerIp;
			_.setCaption(node_data.path, _.manager_ip);
			
			if (!(_.load_flg)) {
				_.load_flg = true;
				_.reloadGrid();
			}
		}
		,/*
		 * reload Grid
		 */
		reloadGrid: function(){
			var _ = this
			;
			
			_.grid.refreshData({
				facilityId: _.facility_id,
				managerIpForSearch: _.manager_ip
			});
		}
		
		,/*
		 * Get scope list
		 */
		createGrid: function(){
			var _ = this;
			
			$.ajax({
				url      : "get_scope_list_table_define"
				,cache   : false
				,dataType: "json"
				,type    : "get"
				,success : function(data_respond){
					// Cache local variants
					var grid = _.grid
					,pager   = grid.$pgr
					;
					// Check validation of data_respond
					if (__.checkJsonError(data_respond) !== true){
						return;
					}
					
					// Set some options for grid
					$.extend(data_respond,{
						url          : "get_scope_list"
						,pager       : pager
						,caption     : [__.getLang("scope"), ": "].join("")
						,sortable    : true
						,viewrecords : true
						,loadComplete: function(){
							var post_data = grid.getGridParam("postData")
							,facility_id
							;
//							for (var pro in data_respond.colModel) {
//								alert(pro + "=" + data_respond[pro]);
//							}
							
							if((facility_id = post_data.facilityId) === undefined){
								facility_id = "";
							}
							if(facility_id === _.facility_id){
								_.load_flg = false;
							}else{
								setTimeout(function(){
									_.reloadGrid();
								}, 1);
							}
							// Set refresh data
							_view.setRefresh();
							
							// Set priority bar
							_.setPriorityStatusBar();
						}
						,ondblClickRow: function(rowid) {
                            var row_data = grid.getRowData(rowid);
                            var node_key = __.getNodeKey(_.getTree(), row_data.facilityId, row_data.manager);
                            
                            if (typeof node_key != 'undefined') {
                                var tree = $(_.tree).dynatree("getTree");
                                tree.activateKey(node_key);
                                $(".dynatree-focused").removeClass("dynatree-focused");
                            }
						}
					});
					if (data_respond.colNames.length == 4) {
						grid.processData(data_respond, ['facilityId', 'manager']);
					} else {
						grid.processData(data_respond, ['facilityId']);
					}
				
					grid.controlSize();
				}
				,error   : __.loadDataError
			});
		}
		
		,/*
		 * Get facility tree
		 */
		getTree: function(){
			return __.fclt_tree.get(this._id);
		}
		
		,/*
		 * Reset data of panes of views
		 */
		resetView: function(tree){
			var _ = this;
			
			_.tree.refreshData(tree);
			_.facility_id = "";
			_.grid.refreshData({
				facilityId: ""
			}, true);
			
			_.setCaption("");
		}
		
		,/*
		 * Refresh data
		 */
		refreshData: function(){
			/** Bug_11 */
			this.grid.refreshData(null, true);
			/***********/
		}
		
		,/*
		 * Bind some action
		 */
		bindAction: function(){
			var _     = this;
			var _btns = _.$btns;
			
			// Bind actions for button in left of pane
			// Bind update grid data
			_btns.children("#update").click(function(){
				/** Bug_11 */
				_.grid.refreshData(null, true);
				/***********/
			});
			// Bind toggle left pane
			_btns.children("#toggle_view").click(function(){
				_.togglePane("west", this);
			});
		}
	});
	
	return view;
};
